#!/usr/bin/python3
"""
## © University of Southampton IT Innovation Centre, 2018
##
## Copyright in this software belongs to University of Southampton
## IT Innovation Centre of Gamma House, Enterprise Road,
## Chilworth Science Park, Southampton, SO16 7NS, UK.
##
## This software may not be used, sold, licensed, transferred, copied
## or reproduced in whole or in part in any manner or form or in or
## on any media by any person other than in accordance with the terms
## of the Licence Agreement supplied with the software, or otherwise
## without the prior written consent of the copyright owners.
##
## This software is distributed WITHOUT ANY WARRANTY, without even the
## implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE, except where stated in the Licence Agreement supplied with
## the software.
##
##      Created By :            Nikolay Stanchev
##      Created Date :          25-04-2018
##      Created for Project :   FLAME
"""


from threading import Thread
from clmcservice.aggregator import Aggregator


class TestAggregator(Thread):

    REPORT_PERIOD = 5  # currently, report period is 5s, that is every 5 seconds the mean delay values for the last 5 seconds are aggregated
    DATABASE = 'E2EMetrics'  # default database the aggregator uses
    DATABASE_URL = 'http://203.0.113.100:8086'  # default database URL the aggregator uses

    def __init__(self, database=DATABASE, database_url=DATABASE_URL, report_period=REPORT_PERIOD):
        """
        Constructs an Aggregator instance.

        :param database: database name to use
        :param database_url: database url to use
        """

        super(TestAggregator, self).__init__()  # call the constructor of the thread

        self.aggregator = Aggregator(database_name=database, database_url=database_url, report_period=report_period)

    def stop(self):
        """
        A method used to stop the thread.
        """

        self.aggregator.stop()

    def set_event_lock(self, event):
        """
         Auxiliary method to set a thread-safe event lock object to the aggregator (used for testing).

         :param event: the event lock object
         """

        setattr(self, 'event', event)

    def run(self):
        if hasattr(self, 'event'):
            self.event.set()

        self.aggregator.run()
